package api;

import com.sunyard.chsm.enums.AlgMode;
import com.sunyard.chsm.param.KeyCreateReq;
import com.sunyard.chsm.param.KeyManageReq;
import com.sunyard.chsm.param.SymDecryptReq;
import com.sunyard.chsm.param.SymDecryptResp;
import com.sunyard.chsm.param.SymEncryptReq;
import com.sunyard.chsm.param.SymEncryptResp;
import com.sunyard.chsm.utils.CodecUtils;
import lombok.extern.slf4j.Slf4j;
import org.junit.jupiter.api.AfterAll;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;
import org.springframework.util.StringUtils;

import java.util.Collections;

/**
 * @author liulu
 * @since 2024/12/18
 */
@Slf4j
public class SymKeyTest extends BaseTest {

    private static final String plain = "hjsu234127qikqwndqqw13412as324";
    private final static byte[] iv = "ghwikdhj1234713v".getBytes();
    private static Long keyId;

    @BeforeAll
    public static void beforeAll() {
        keyId = execute("/key/gen", KeyCreateReq.builder().keyTemplateCode(keyTemplate).genNumber(1).build(), Long.class);
        Assertions.assertTrue(keyId > 0);
    }

    @AfterAll
    public static void afterAll() {
        KeyManageReq keyManageReq = new KeyManageReq();
        keyManageReq.setIds(Collections.singletonList(keyId));
        execute("/key/disable", keyManageReq, Void.class);
        execute("/key/destroy", keyManageReq, Void.class);
    }

    @Test
    public void testEncrypt() {

        SymEncryptReq symEncryptReq = new SymEncryptReq();
        symEncryptReq.setKeyId(keyId);
        symEncryptReq.setPlainData(CodecUtils.encodeBase64(plain.getBytes()));
        symEncryptReq.setIv(CodecUtils.encodeBase64(iv));
        symEncryptReq.setMode(AlgMode.CBC);

        SymEncryptResp symEncryptResp = execute("/sym/encrypt", symEncryptReq, SymEncryptResp.class);
        log.info("SymEncryptResp: {}", symEncryptResp);
        Assertions.assertNotNull(symEncryptResp);
        Assertions.assertTrue(StringUtils.hasText(symEncryptResp.getKeyIndex()));
        byte[] cipherData = CodecUtils.decodeBase64(symEncryptResp.getCipherData());
        Assertions.assertEquals(32, cipherData.length);

        SymDecryptReq decryptReq = new SymDecryptReq();
        decryptReq.setKeyId(keyId);
        decryptReq.setKeyIndex(symEncryptResp.getKeyIndex());
        decryptReq.setIv(CodecUtils.encodeBase64(iv));
        decryptReq.setMode(AlgMode.CBC);
        decryptReq.setCipherData(symEncryptResp.getCipherData());
        SymDecryptResp decryptResp = execute("/sym/decrypt", decryptReq, SymDecryptResp.class);
        String calPlain = new String(CodecUtils.decodeBase64(decryptResp.getPlainData()));
        log.info("SymDecryptResp: {}, {}", calPlain, decryptResp);
        Assertions.assertNotNull(decryptResp);
        Assertions.assertEquals(plain, calPlain);
    }


}
